@@ -1,5 +1,10 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+'''
+Module: AutoBot
+Purpose: trading bot deplyed by AutoTrader
+Author: Kieran Mackle
+'''
 
 import sys
 import os
@@ -19,7 +24,7 @@ from autotrader.autostream import AutoStream
 
 class AutoTraderBot():
     '''
-    AutoTrader Bot.
+    AutoTrader Bot
     ---------------
     
     Attributes
@@ -334,7 +339,7 @@ class AutoTraderBot():
                     data = MTF_data[first_granularity]
                     quote_data = quote_data
                 
-                if len(MTF_data) == 1:
+                if MTF_data is not None and len(MTF_data) == 1:
                     MTF_data = None
                 
                 if int(self.verbosity) > 1:
@@ -855,4 +860,10 @@ class AutoTraderBot():
         end_range       = len(self.data)
 
         return start_range, end_range
+    
+    def _replace_data(self, data):
+        ''' Function to replace the data assigned locally and to the strategy. '''
+        
+        self.data = data
+        self.strategy.data = data
     
\ No newline at end of file
